%% ADF-tests %%
%% Housekeeping 
clear; clc; close all hidden;
addpath('data_quarterly')
addpath('utilities')
addpath('ADF_test_functions')

%% Data loading 
load("dates.mat");
load("brentspot");
load('CPI_US');
load("RGDP_mainland.mat");
load("GECON.mat"); 
load("oilprod.mat");
load("employment.mat");
load('KPI_Norway');
load("wage.mat");


load("rgdp_EOGS.mat");
load("empl_oil_sector.mat");
load("wage_oil_sector.mat");

load("rgdp_FCA.mat");
load("empl_FCA_sector.mat");
load("wage_FCA_sector.mat");

load("rgdp_MIME.mat");
load("empl_MIME_sector.mat");
load("wage_MIME_sector.mat");

load("rgdp_BC.mat");
load("empl_BC_sector.mat");
load("wage_BC_sector.mat");

load("rgdp_SB.mat");
load("empl_SB_sector.mat");
load("wage_SB_sector.mat");
%% Real values 
rop = (brentspot./CPI_US)*100; 
real_wage_ME = (wage./KPI_Norway)*100;
real_wage_oil_sector = (wage_oil_sector./KPI_Norway)*100;
real_wage_FCA_sector = (wage_FCA_sector./KPI_Norway)*100;
real_wage_MIME_sector = (wage_MIME_sector./KPI_Norway)*100;
real_wage_BC_sector = (wage_BC_sector./KPI_Norway)*100;
real_wage_SB_sector = (wage_SB_sector./KPI_Norway)*100;

%% Global Crude Oil Production - raw data with constant and trend 
p = 1;      % There is a constant and a time trend
nlag = 1;   % Start with 1 lag
ADFtest3 = unitRootTest(oilprod,p,nlag,'vname','GCOP');

%% Global Crude Oil Production - log-level with constant and trend 

oilprod_log = log(oilprod)  
% Do a ADF test
p = 1;      % There is a constant and a time trend
nlag = 1;   % Start with 1 lag
ADFtest3 = unitRootTest(oilprod_log,p,nlag,'vname','GCOP');

%% Global Crude Oil Production - log-level and with a constant 

oilprod_log = log(oilprod)
% Do a ADF test
p = 0;      % There is a constant, but no time trend
nlag = 1;   % Start with 1 lag
ADFtest3 = unitRootTest(oilprod_log,p,nlag,'vname','GCOP');

%% Global Crude Oil Production - detrendend and with a constant

oilprod_detrended = detrend(log(oilprod),1)
   
% Do a ADF test
p = 0;      % There is a constant, but no time trend
nlag = 1;   % Start with 1 lag
ADFtest3 = unitRootTest(oilprod_detrended,p,nlag,'vname','GCOP');

%% GECON - raw data, with a constant and a trend 

p = 1;      % There is a constant and a time trend
nlag = 1;   % Start with 1 lag
ADFtest3 = unitRootTest(GECON,p,nlag,'vname','GECON');

%% GECON - log-level with constant and trend 
GECON_log = log(GECON)
   
% Do a ADF test
p = 1;      % There is a constant and a time trend
nlag = 1;   % Start with 1 lag
ADFtest3 = unitRootTest(GECON_log,p,nlag,'vname','GECON');

% ADF statistic = -10.734 < -3.464. We reject the null hypothesis
% with a unit root at the 1% critical value. The growth of real
% GDP is stationary. When looking at the plotted graph, we see that it is
% stationary, because it's mean is reverting with a constant variance. 
% The ADF test proves this.



%% GECON - log-level and with a constant 

GECON_log = log(GECON)
   
% Do a ADF test
p = 0;      % There is a constant, but no time trend
nlag = 1;   % Start with 1 lag
ADFtest3 = unitRootTest(GECON_log,p,nlag,'vname','Real GDP growth');

%% GECON - detrended and with a constant 

GECON_detrended = detrend(log(GECON),1)
   
% Do a ADF test
p = 0;      % There is a constant, but no time trend
nlag = 1;   % Start with 1 lag
ADFtest3 = unitRootTest(GECON_detrended,p,nlag,'vname','GECON');

%% ROP - raw data, with a constant and a trend 

p = 1;      % There is a constant and a time trend
nlag = 1;   % Start with 1 lag
ADFtest3 = unitRootTest(rop,p,nlag,'vname','rop');
 
%% ROP - log-level with constant and trend 
rop_log = log(rop)

% Do a ADF test
p = 1;      % There is a constant and a time trend
nlag = 1;   % Start with 1 lag
ADFtest3 = unitRootTest(rop_log,p,nlag,'vname','rop');

% ADF statistic = -10.734 < -3.464. We reject the null hypothesis
% with a unit root at the 1% critical value. The growth of real
% GDP is stationary. When looking at the plotted graph, we see that it is
% stationary, because it's mean is reverting with a constant variance. 
% The ADF test proves this.



%% ROP - log-level and with a constant 

rop_log = log(rop)
   
% Do a ADF test
p = 0;      % There is a constant, but no time trend
nlag = 1;   % Start with 1 lag
ADFtest3 = unitRootTest(rop_log,p,nlag,'vname','rop');

%% ROP - detrended and with a constant 

rop_detrended = detrend(log(rop),1)
   
% Do a ADF test
p = 0;      % There is a constant, but no time trend
nlag = 1;   % Start with 1 lag
ADFtest3 = unitRootTest(rop_detrended,p,nlag,'vname','rop');
%% Sector-specific GDP - log levels, constant and with a trend 


p = 1;      % There is a constant and a time trend
nlag = 1;   % Start with 1 lag
ADFtest3 = unitRootTest(log(RGDP_mainland),p,nlag,'vname','gdp-ME');
%%
ADFtest3 = unitRootTest(log(rgdp_EOGS),p,nlag,'vname','gdp-EOGS');
%%
ADFtest3 = unitRootTest(log(rgdp_FCA),p,nlag,'vname','gdp-FCA');
%%
ADFtest3 = unitRootTest(log(rgdp_MIME),p,nlag,'vname','gdp-MIME');
%%
ADFtest3 = unitRootTest(log(rgdp_BC),p,nlag,'vname','gdp-BC');
%%
ADFtest3 = unitRootTest(log(rgdp_SB),p,nlag,'vname','gdp-SY');

%% Sector-specific employment - log levels constant and with a trend 

p = 1;      % There is a constant, but no time trend
nlag = 1;   % Start with 1 lag
ADFtest3 = unitRootTest(log(employment),p,nlag,'vname','empl-ME');
%%
ADFtest3 = unitRootTest(log(empl_oil_sector),p,nlag,'vname','empl-EOGS');
%%
ADFtest3 = unitRootTest(log(empl_FCA_sector),p,nlag,'vname','empl-FCA');
%%
ADFtest3 = unitRootTest(log(empl_MIME_sector),p,nlag,'vname','empl-MIME');
%%
ADFtest3 = unitRootTest(log(empl_BC_sector),p,nlag,'vname','empl-BC');
%%
ADFtest3 = unitRootTest(log(employment),p,nlag,'vname','empl-ME');
%%
ADFtest3 = unitRootTest(log(empl_SB_sector),p,nlag,'vname','empl-SY');


%% Sector-specific real wage - log levels constant and with a trend 

p = 1;      % There is a constant and a time trend
nlag = 1;   % Start with 1 lag
ADFtest3 = unitRootTest(log(real_wage_ME),p,nlag,'vname','rw-ME');
%%
ADFtest3 = unitRootTest(log(real_wage_oil_sector),p,nlag,'vname','rw-EOGS');
%%
ADFtest3 = unitRootTest(log(real_wage_FCA_sector),p,nlag,'vname','rw-FCA');
%%
ADFtest3 = unitRootTest(log(real_wage_MIME_sector),p,nlag,'vname','rw-MIME');
%%
ADFtest3 = unitRootTest(log(real_wage_BC_sector),p,nlag,'vname','rw-BC');
%%
ADFtest3 = unitRootTest(log(real_wage_SB_sector),p,nlag,'vname','rw-SY');


%% Sector-specific GDP - detrended with a constant
rgdp_detrended_ME = detrend(log(RGDP_mainland),1);
rgdp_detrended_EOGS = detrend(log(rgdp_EOGS),1);
rgdp_detrended_FCA = detrend(log(rgdp_FCA),1);
rgdp_detrended_MIME = detrend(log(rgdp_MIME),1);
rgdp_detrended_BC = detrend(log(rgdp_BC),1);
rgdp_detrended_SB = detrend(log(rgdp_SB),1);

p = 0;      % There is a constant, but no time trend
nlag = 1;   % Start with 1 lag
ADFtest3 = unitRootTest(rgdp_detrended_ME,p,nlag,'vname','empl-ME');
%%
ADFtest3 = unitRootTest(rgdp_detrended_EOGS,p,nlag,'vname','empl-EOGS');
%%
ADFtest3 = unitRootTest(rgdp_detrended_FCA,p,nlag,'vname','empl-FCA');
%%
ADFtest3 = unitRootTest(rgdp_detrended_MIME,p,nlag,'vname','empl-MIME');
%%
ADFtest3 = unitRootTest(rgdp_detrended_BC,p,nlag,'vname','empl-BC');
%%
ADFtest3 = unitRootTest(rgdp_detrended_SB,p,nlag,'vname','empl-SY');

%% Sector-specific employment - detrended with a constant
empl_oil_sector_detrended = detrend(log(empl_oil_sector),1)
empl_FCA_sector_detrended = detrend(log(empl_FCA_sector),1)
empl_BC_sector_detrended = detrend(log(empl_BC_sector),1)
empl_MIME_sector_detrended = detrend(log(empl_MIME_sector),1)
empl_ME_detrended = detrend(log(employment),1);
empl_SB_sector_detrended = detrend(log(empl_SB_sector),1)

p = 0;      % There is a constant, but no time trend
nlag = 1;   % Start with 1 lag
ADFtest3 = unitRootTest(empl_ME_detrended,p,nlag,'vname','empl-ME');
%%
ADFtest3 = unitRootTest(empl_oil_sector_detrended,p,nlag,'vname','empl-EOGS');
%%
ADFtest3 = unitRootTest(empl_FCA_sector_detrended,p,nlag,'vname','empl-FCA');
%%
ADFtest3 = unitRootTest(empl_MIME_sector_detrended,p,nlag,'vname','empl-MIME');
%%
ADFtest3 = unitRootTest(empl_BC_sector_detrended,p,nlag,'vname','empl-BC');
%%
ADFtest3 = unitRootTest(empl_SB_sector_detrended,p,nlag,'vname','empl-SY');

%% Sector-specific real wage - detrended with a constant
real_wage_ME_detrended = detrend(log(real_wage_ME),1)
real_wage_oil_sector_detrended = detrend(log(real_wage_oil_sector),1); %Real wage 
real_wage_FCA_sector_detrended = detrend(log(real_wage_FCA_sector),1); %Real wage
real_wage_MIME_sector_detrended = detrend(log(real_wage_MIME_sector),1); %Real wage
real_wage_BC_sector_detrended = detrend(log(real_wage_BC_sector),1); %Real wage
real_wage_SB_sector_detrended = detrend(log(real_wage_SB_sector),1);

p = 0;      % There is a constant, but no time trend
nlag = 1;   % Start with 1 lag
ADFtest3 = unitRootTest(real_wage_ME_detrended,p,nlag,'vname','rw-ME');
%%
ADFtest3 = unitRootTest(real_wage_oil_sector_detrended,p,nlag,'vname','rw-EOGS');
%%
ADFtest3 = unitRootTest(real_wage_FCA_sector_detrended,p,nlag,'vname','rw-FCA');
%%
ADFtest3 = unitRootTest(real_wage_MIME_sector_detrended,p,nlag,'vname','rw-MIME');
%%
ADFtest3 = unitRootTest(real_wage_BC_sector_detrended,p,nlag,'vname','rw-BC');

%%
ADFtest3 = unitRootTest(real_wage_SB_sector_detrended,p,nlag,'vname','rw-SY');


