%% Housekeeping and working directory 
clear; clc; close all hidden;
addpath('data_quarterly')
addpath('utilities')
addpath('ADF_test_functions')


%% Converting dates from numerical values to datetime
%%dates = datetime(Dates,'convertfrom', 'Excel');

%% Data loading 
load("dates.mat");
load("brentspot");
load('CPI_US');
load("RGDP_mainland.mat");
load("GECON.mat"); 
load("oilprod.mat");
load("employment.mat");
load('KPI_Norway');
load("wage.mat");



%% Plots of data 
% Do subplot when all data is collected
figure(1)
subplot(3, 3, 1); plot(dates(1:111), oilprod); title('Global Crude Oil Production');
subplot(3, 3, 2); plot(dates, GECON); title('Global Economic Conditions Indicator');
subplot(3, 3, 3); plot(dates,  brentspot); title('Euorope Brent Spot Prices of Crude Oil');
subplot(3, 3, 4); plot(dates, RGDP_mainland); title('Real GDP ME');
subplot(3, 3, 5); plot(dates, employment); title('Employment ME');
subplot(3, 3, 6); plot(dates,wage); title('Nominal Wage ME');

set(findobj(gcf,'type','Line'),'LineWidth', 1.5);

%% Converting Oil prices to real value 

rop = (brentspot./CPI_US)*100; %Real oil price 
real_wage= (wage./KPI_Norway)*100; %Real wage
%% Plot of European Brent Spot Prices of Crude Oil and Real oil prices
figure(2)
plot(dates,brentspot);
title('European Brent Spot Prices of Crude Oil');
    hold on
plot(dates,rop); 
    hold off
legend({'Nominal','Real'},'Location','northwest');
set(findobj(gcf,'type','Line'),'LineWidth', 2);

%% First difference of Natural log 

oilprod_detrended = detrend(log(oilprod),1);
rgdp_detrended = detrend(log(RGDP_mainland),1);
rop_log=(log(rop));
employment_detrended = detrend(log(employment),1);
real_wage_detrended = detrend(log(real_wage),1);
%%
rop_diff = 100*diff(rop_log)

figure(3)
plot(dates(2:112),rop_diff)
title('Changes in the Real Oil Price ')
set(findobj(gcf,'type','Line'),'LineWidth', 1);

%% Creating a Vector of our variables 

Y = [oilprod_detrended,GECON(1:111),rop_log(1:111),rgdp_detrended(1:111),employment_detrended(1:111), real_wage_detrended(1:111)]
y_Names = {'Response of gcop to gcop',...
          'Response of gecon to gcop',...
          'Response of rop to gcop',...
          'Response of gdp to gcop',...
          'Response of empl to gcop',...
          'Response of rw to gcop'};

%% Check for Stability
% Specify number of lags (result from the section above)
nlag_max = 1; 

% Specify deterministic variables
% deterministic = 0: do not include constant or trend
% deterministic = 1: include constant
% deterministic = 2: include constant and linear trend
deterministic = 2;

% Estimate the VAR
varModel = estimateVAR(Y, nlag_max, deterministic);


% Check for stability using eigenvalues
max_eigvals = (abs(eig(varModel.betac)));
fprintf('Maximum eigenvalue of the companion form matrix is %g\n',max_eigvals)
figure
plot(max_eigvals,"o",MarkerSize=8,Color='blue')
sgtitle('Mainland Economy')
% Conclusion: 
% The VAR is stable because all eigenvalues are less than one in absolute value.

%% Computing IRFs 
% Number of bootstraps (to simulate confidence bands)
draws = 1000;

% Impulse-response horizon
nirf = 20; % 10 years = 40 quarters

% Specify confidence bands
percentiles = [0.05, 0.95]; % 90% confidence bands

% Normalise the shock size to 1% 
normalizeShocks = 1;

% Compute the SVAR model using Cholesky decomposition 
svarModel = cholIdentification(varModel, draws, nirf, percentiles, normalizeShocks);

% Plot impulse response functions
plotIRF(svarModel, y_Names)

% Interpret 
%%