function yhatF=forecastArModel(betas,yt,p,H)
%% Function to forecast from an AR(p) model with drift
% y_{t} = beta_{0} + beta_{1}y_{t-1} + ... + beta_{p}y_{t-p} + + e_{t}, 
% where e_{t}~N(0,sigma^2) is an iid error. 
%
% Inputs: 
%   betas := (1+p)x1 vector of AR coefficients - intercept is listed first
%   yt := Tx1 vector of data points
%   p := scalar representing the number of lags in the AR model
%   H := scalar representing the maximum forecast horizon
%
% Outputs:
%   yhat := Hx1 vector of forecasts

% initial conditioning vector 
ycond = yt(end:-1:end-p+1)';

yhatF = nan(H,1);
for h=1:H    
    % add the constant to the conditioning information and forecast
    yhatF(h) = [1 ycond]*betas;    
    % update the conditioning vector with previous periods forecast
    ycond = [yhatF(h) ycond(1:end-1)];    
end